.. py:currentmodule:: rubin_sim

.. _rubin-sim-index:

#########
rubin_sim
#########

Helping simulate and evaluate the performance of
Rubin C. Observatory's Legacy Survey of Space and Time (the LSST),
through evaluating prototypes of various analysis, simulating photometry
and providing a framework for analyzing survey strategy progress and outcomes.


.. toctree::
    :maxdepth: 2

    Introduction <introduction>
    Installation <installation>
    User Guide <user-guide>
    API <api>